@@ -95,6 +95,18 @@ void AnyMeal::init()
                        FormatterListener::OUTPUT_METHOD_HTML,
                        HTMLENCODING, "" ) );
 
+  splash->message( i18n( "Initialising fast HTML ..." ) );
+  recipeToHTML =
+    XSLCompilerPtr
+    ( new XSLCompiler( findAnyMealFile( "appdata", "scripts/recipeToHTML.xsl" ),
+                       FormatterListener::OUTPUT_METHOD_HTML,
+                       HTMLENCODING,
+                       findAnyMealFile( "appdata", "scripts/anymeal.xsd" ) ) );
+  recipeToHTML->setParam( "lfile", std::string( "\"file://" ) +
+                          dictionaryFile() + "\"" );
+  recipeToHTML->setParam( "lname", std::string( "\"" ) + anyMealLanguage() +
+                          "\"" );
+
   splash->message( i18n( "Initialising Formatted Objects export ..." ) );
   docbookToFO =
     XSLCompilerPtr
@@ -126,6 +138,7 @@ void AnyMeal::destroy()
   recipeMLToRecipe.reset();
   recipeToRecipeML.reset();
   docbookToFO.reset();
+  recipeToHTML.reset();
   docbookToHTML.reset();
   recipeToMealMaster.reset();
   recipeToDocbook.reset();
@@ -300,7 +313,7 @@ void AnyMeal::displayRecipe( int id )
     RecipeDisplay *recipeDisplay =
       new RecipeDisplay( workSpace, 0, WDestructiveClose );
     recipeDisplay->setRecipeToHTML
-      ( CompilerPtr( new ChainedCompiler( recipeToDocbook, docbookToHTML ) ) );
+      ( recipeToHTML );
     recipeDisplay->setRecipe( id, xmlOut.str() );
     connect( this,
              SIGNAL( changeRecipeId( int, int, const QString &, const QString & ) ),
@@ -1042,7 +1055,7 @@ void AnyMeal::databaseInfo()
 
 void AnyMeal::fileImportRecipeML()
 {
-#if 1
+#if 0
   try {
 
     QStringList fileNames =
@@ -1101,7 +1114,13 @@ void AnyMeal::fileImportRecipeML()
   try {
 
     ImportRecipeMLDialog importRecipeMLDialog( this );
-    importRecipeMLDialog.exec();
+    importRecipeMLDialog.cookBook = cookBook;
+    importRecipeMLDialog.recipeMLToRecipe = recipeMLToRecipe;
+    if ( importRecipeMLDialog.exec() )
+      statusBar()->message( i18n( "Imported RecipeML file(s)." ),
+                            STATUSDISPLAYTIME );
+    else
+      statusBar()->message( i18n( "Import aborted." ), STATUSDISPLAYTIME );
 
   } catch ( Error &e ) {
     
