@@ -4,7 +4,7 @@
 ln -s ../icons/hi32-action-checked.png checked.png
 ln -s ../icons/hi32-action-connect.png connect.png
 ln -s ../icons/hi32-action-contents.png contents.png
-ln -s ../icons/hi32-action-database.png database.png
+ln -s ../icons/hi32-action-dblogo.png dblogo.png
 ln -s ../icons/hi32-action-delete.png delete.png
 ln -s ../icons/hi32-action-deleteRecipe.png deleteRecipe.png
 ln -s ../icons/hi32-action-editnew.png editnew.png
