@@ -34,7 +34,7 @@
 #include "mysqlDatabase.hpp"
 #include "mysqlNetwork.hpp"
 #include "recoder.hpp"
-#include "storeErroneousHandler.hpp"
+#include "mealMasterStoreErroneousHandler.hpp"
 #include "utils.hpp"
 #include "xslCompiler.hpp"
 #include "xsu.hpp"
@@ -174,15 +174,15 @@ bool cli(void) throw (Error)
       switch ( compiler ) {
       case MM2AnyMeal: {
         shared_ptr< ostream > stream;
-        ParseErrorHandlerPtr parseErrorHandler;
+        MealMasterParseErrorHandlerPtr parseErrorHandler;
 
         if ( parseErrorFileName != NULL ) {
           stream = shared_ptr< ostream >
             ( new ofstream( parseErrorFileName, ios::binary ) );
-          parseErrorHandler = ParseErrorHandlerPtr
-            ( new StoreErroneousHandler( stream.get(), parseErrorFileName ) );
+          parseErrorHandler = MealMasterParseErrorHandlerPtr
+            ( new MealMasterStoreErroneousHandler( stream.get(), parseErrorFileName ) );
         } else
-          parseErrorHandler = ParseErrorHandlerPtr( new ParseErrorHandler );
+          parseErrorHandler = MealMasterParseErrorHandlerPtr( new MealMasterParseErrorHandler );
 
         MealMasterCompiler( -1, parseErrorHandler ).translate( *input, *output );
         break;}
@@ -429,7 +429,7 @@ int main( int argc, char *argv[] )
       ( "anymeal", I18N_NOOP( "AnyMeal" ), VERSION,
         I18N_NOOP( "recipe database application" ),
         KAboutData::License_GPL,
-        I18N_NOOP( "Copyright (C) 2002, 2003, 2004, 2005, Jan Wedekind, "
+        I18N_NOOP( "Copyright (C) 2002, 2003, 2004, 2005, 2006, Jan Wedekind, "
                    "Sheffield, United Kingdom" ),
         I18N_NOOP( "AnyMeal comes with ABSOLUTELY NO WARRANTY.\n"
                    "This is free software, and you are welcome to "
@@ -442,6 +442,10 @@ int main( int argc, char *argv[] )
     about.addAuthor( "Jan Wedekind", I18N_NOOP( "Main developer" ),
                      "jan@wedesoft.de",
                      "http://www.wedesoft.de/" );
+    about.addCredit( "Sandro Tosi",
+                     I18N_NOOP( "Debian-package and man-page." ),
+                     "matrixhasu@altervista.org",
+                     "http://matrixhasu.altervista.org/" );
     about.addCredit( "Scott Welliver",
                      I18N_NOOP( "Project inspired from original "
                                 "Mealmaster-software." ),
